# Copyright (c) 2026 Red Hat Inc.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

PVLAN = "pvlan"
PVLAN_COMMUNITY = "pvlan_community"
PVLAN_TYPE = "pvlan_type"

ISOLATED_TYPE = 'isolated'
PROMISCUOUS_TYPE = 'promiscuous'
COMMUNITY_TYPE = 'community'
COMMUNITY_NAME_MAX_LEN = 232

PVLAN_TYPES = [ISOLATED_TYPE, PROMISCUOUS_TYPE, COMMUNITY_TYPE]

COMMUNITY_NAME_REGEX = (
    "[a-zA-Z_.][a-zA-Z_.0-9]{0,%d}$" % (COMMUNITY_NAME_MAX_LEN - 1)
)
